﻿using System;
using System.Collections.ObjectModel;
using System.Diagnostics;
using PCLStorage;
using Xamarin.Forms;

namespace Bring
{
	public partial class BringListPage : ContentPage
	{
		ObservableCollection<ItemClass> _bringData = new ObservableCollection<ItemClass>();

		public BringListPage()
		{
			InitializeComponent();

			LoadAndSetListView();

			ToolbarItems.Add(new ToolbarItem
			{
				Text = "入力",
				Command = new Command( async () =>
				{
					var result = await DependencyService.Get<IEntryAlert>().Show(
						"親に言われた数字を入力", App._bringUInt.ToString(), "OK", "Cancel");
					if (result.IsOK)
					{
						try
						{
							UInt32 parse = UInt32.Parse(result.Text);
							App._bringUInt = parse;
							for (var i = 0; i < 32; i++)
								App._bring[i] = false;
							SaveData();
							SetListView();
						}
						catch
						{
							Debug.WriteLine("BringListPage.ToolBarItems Error");
						}
					}
				})
			});
			ToolbarItems.Add(new ToolbarItem
			{
				Text = "親",
				Command = new Command(async() =>
				{
					await Navigation.PushAsync(new ParentPage());
				})
			});
		}

		private async void LoadAndSetListView()
		{
			IFolder rootFolder = FileSystem.Current.LocalStorage;
			var res = await rootFolder.CheckExistsAsync(App.BRING_DATA_FILE);
			if (res == ExistenceCheckResult.FileExists)
			{
				IFile file = await rootFolder.GetFileAsync(App.BRING_DATA_FILE);
				string data = await file.ReadAllTextAsync();
				App._bringUInt = UInt32.Parse(data);
			}
			SetListView();
		}

		private void SetListView()
		{
			_bringData.Clear();
			var four = new UInt32[] { 1, 2, 4, 8 };
			for (var i = 0; i < 32; i++)
			{
				var shift = (int)(i / 4) * 4;
				if ((App._bringUInt & (four[i % 4] << shift)) != 0)
					_bringData.Add(new ItemClass { Id = i.ToString(), Text = App._bringItem[i], Checked = App._bring[i] });
			}
			_bringListView.ItemsSource = _bringData;
		}

		protected void OnChanged(object sender, EventArgs e)
		{
			try
			{
				var item = sender as SwitchCell;
				var id = int.Parse(item.ClassId);
				if (App._bring[id] != item.On)
				{
					App._bring[id] = item.On;
				}
			}
			catch
			{
				Debug.WriteLine("BringListPage.OnChange Error");
			}
		}

		private async void SaveData()
		{
			string data = App._bringUInt.ToString();

			IFolder rootFolder = FileSystem.Current.LocalStorage;
			IFile file = await rootFolder.CreateFileAsync(App.BRING_DATA_FILE, CreationCollisionOption.ReplaceExisting);
			await file.WriteAllTextAsync(data);
		}
	}
}
